/*
    module/mite.h
    Hardware driver for NI Mite PCI interface chip

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1999 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _MITE_H_
#define _MITE_H_

#include <comedi_module.h>
#include <linux/pci.h>
#ifdef PCI_SUPPORT_VER1
#include <linux/bios32.h>
#endif


#define PCI_VENDOR_ID_NATINST		0x1093


struct mite_struct{
	struct mite_struct *next;
	int used;

#ifdef PCI_SUPPORT_VER1
	unsigned char pci_bus;
	unsigned char pci_device_fn;
	int irq;
	int device_id;
#else
	struct pci_dev *pcidev;
#endif
	unsigned long mite_phys_addr;
	void *mite_io_addr;
	unsigned long daq_phys_addr;
	void *daq_io_addr;
};

extern struct mite_struct *mite_devices;

#ifdef PCI_SUPPORT_VER1
#define mite_irq(a)		((a)->irq)
#define mite_device_id(a)	((a)->device_id)
#else
#define mite_irq(a)		((a)->pcidev->irq)
#define mite_device_id(a)	((a)->pcidev->device)
#endif

#define mite_iobase(a)		((a)->daq_io_addr)


void mite_init(void);
void mite_cleanup(void);
int mite_setup(struct mite_struct *mite);
void mite_unsetup(struct mite_struct *mite);


/* DMA base for chan 0 is 0x500, chan 1 is 0x600 */

#define MITE_CHOR		0x500
#define CHOR_DMARESET			(1<<31)
#define CHOR_SET_SEND_TC		(1<<11)
#define CHOR_CLR_SEND_TC		(1<<10)
#define CHOR_SET_LPAUSE			(1<<9)
#define CHOR_CLR_LPAUSE			(1<<8)
#define CHOR_CLRDONE			(1<<7)
#define CHOR_CLRRB			(1<<6)
#define CHOR_CLRLC			(1<<5)
#define CHOR_FRESET			(1<<4)
#define CHOR_ABORT			(1<<3)
#define CHOR_STOP			(1<<2)
#define CHOR_CONT			(1<<1)
#define CHOR_START			(1<<0)
#define CHOR_PON			(CHOR_CLR_SEND_TC|CHOR_CLR_LPAUSE)

#define MITE_CHCR		0x504
#define MITE_TCR		0x508
#define MITE_MCR		0x50c
#define MITE_MAR		0x510
#define MITE_DCR		0x514
#define MITE_DAR		0x518
#define MITE_LKCR		0x51c
#define MITE_LKAR		0x520
#define MITE_LLKAR		0x524
#define MITE_BAR		0x528
#define MITE_BCR		0x52c
#define MITE_SAR		0x530
#define MITE_WSCR		0x534
#define MITE_WSER		0x538
#define MITE_CHSR		0x53c
#define MITE_FCR		0x540

#define MITE_FIFO		0x80
#define MITE_FIFOEND		0xff

#define MITE_AMRAM		0x00
#define MITE_AMDEVICE		0x01
#define MITE_AMHOST_A32_SINGLE	0x09
#define MITE_AMHOST_A24_SINGLE	0x39
#define MITE_AMHOST_A16_SINGLE	0x29
#define MITE_AMHOST_A32_BLOCK	0x0b
#define MITE_AMHOST_A32D64_BLOCK	0x08
#define MITE_AMHOST_A24_BLOCK	0x3b



#endif

